/** @type {import('tailwindcss').Config} */
module.exports = {
  content: [
    "./templates/**/*.html",
    "./static/**/*.js",
    "./static/css/input.css"
  ],
  darkMode: 'class',
  theme: {
    extend: {
      spacing: {
        '72': '18rem',
        '84': '21rem',
        '96': '24rem'
      },
      colors: {
        // Mercedes-Benz Corporate Colors
        'mercedes': {
          'black': '#000000',
          'silver': '#C0C0C0',
          'dark-gray': '#1a1a1a',
          'light-gray': '#f5f5f5',
          'platinum': '#E5E4E2',
          'charcoal': '#36454F',
          'steel': '#71797E'
        },
        // Dark Mode optimierte Farben - Verbessert
        'dark': {
          'bg': '#0f172a',        // Dunkler Hintergrund
          'bg-secondary': '#131c2e', // Sekundärer Hintergrund noch dunkler
          'surface': '#1e293b',
          'surface-hover': '#334155',
          'card': '#1e293b',      // Dunklere Kartenfarbe für besseren Kontrast
          'card-hover': '#334155', // Dunklerer Hover-Zustand
          'text': '#f8fafc',
          'text-secondary': '#e2e8f0',
          'text-muted': '#94a3b8',
          'text-disabled': '#64748b',
          'border': '#334155',
          'border-light': '#475569',
          'hover': '#334155',     // Dunklerer Hover-Zustand
          'focus': '#475569',
          'accent': '#4f46e5'
        },
        // Light Mode optimierte Farben - Verbessert
        'light': {
          'bg': '#ffffff',
          'bg-secondary': '#f8fafc',
          'surface': '#f7fafc',
          'surface-hover': '#edf2f7',
          'card': '#ffffff',
          'card-hover': '#f7fafc',
          'text': '#1a202c',
          'text-secondary': '#2d3748',
          'text-muted': '#4a5568',
          'text-disabled': '#a0aec0',
          'border': '#e2e8f0',
          'border-light': '#edf2f7',
          'hover': '#f1f5f9',
          'focus': '#e2e8f0',
          'accent': '#3b82f6'
        },
        // Status Farben - Erweitert
        'status': {
          'online': '#10b981',
          'offline': '#ef4444',
          'warning': '#f59e0b',
          'info': '#3b82f6',
          'success': '#059669',
          'error': '#dc2626',
          'pending': '#8b5cf6',
          'processing': '#06b6d4',
          'unknown': '#6b7280'
        },
        // Printer Status Farben - Erweitert
        'printer': {
          'ready': '#10b981',
          'busy': '#f59e0b',
          'error': '#ef4444',
          'offline': '#6b7280',
          'maintenance': '#8b5cf6',
          'initializing': '#06b6d4'
        },
        // Job Status Farben - Erweitert
        'job': {
          'queued': '#6b7280',
          'printing': '#3b82f6',
          'completed': '#10b981',
          'failed': '#ef4444',
          'cancelled': '#f59e0b',
          'paused': '#8b5cf6',
          'retrying': '#f97316'
        },
        // Accent Farben - Erweitert
        'accent': {
          'primary': '#3b82f6',
          'secondary': '#8b5cf6',
          'tertiary': '#06b6d4',
          'quaternary': '#10b981',
          'quinary': '#f97316'
        },
        // Gradient Farben - Erweitert
        'gradient': {
          'from-blue': '#3b82f6',
          'to-purple': '#8b5cf6',
          'from-green': '#10b981',
          'to-blue': '#3b82f6',
          'from-purple': '#8b5cf6',
          'to-pink': '#ec4899',
          'from-orange': '#f97316',
          'to-red': '#ef4444'
        }
      },
      typography: {
        DEFAULT: {
          css: {
            'code::before': {
              content: 'none',
            },
            'code::after': {
              content: 'none',
            },
          },
        },
      },
      boxShadow: {
        'mercedes': '0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06)',
        'card-dark': '0 4px 6px -1px rgba(0, 0, 0, 0.3), 0 2px 4px -1px rgba(0, 0, 0, 0.2)',
      }
    },
  },
  plugins: [],
} 